# together_worker

## Setup dev

```console
make install
```

## Publish to PyPi

GitHub repo > Releases > Draft a new Release > Choose a tag > Create new tag on publish >

Name the tag using the current version from pyproject.toml with a "v" e.g. `v1.0.9`.

> Publish Release

In the repo toolbar select > Actions

- Verify the publish workflow is running and completes successfully

